#
# spec file for package mgp
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mgp
Version:        1.13a
Release:        121.8
Summary:        MagicPoint, an X Window System Presentation Tool
License:        BSD-3-Clause
Group:          Productivity/Publishing/Presentation
URL:            http://member.wide.ad.jp/wg/mgp/
Source:         magicpoint-%{version}.tar.bz2
Source1:        README.SUSE
Patch1:         magicpoint-ia64.diff
Patch2:         magicpoint-imlib2.patch
Patch3:         magicpoint-%{version}-tffonts.diff
Patch5:         magicpoint-%{version}-sample.diff
Patch6:         magicpoint-%{version}-nonvoid.diff
Patch7:         magicpoint-%{version}-cflags.diff
Patch8:         magicpoint-%{version}-compile-warning.diff
Patch9:         magicpoint-%{version}-null.diff
Patch10:        magicpoint-%{version}-xft-rendering-fix.diff
Patch11:        magicpoint-%{version}-lib64.diff
Patch13:        magicpoint-%{version}-warnings.patch
Patch14:        mgp-bilinear-zoom.diff
Patch15:        mgp-imlib2-segfault-fix.diff
Patch16:        mgp-alpha-channel.diff
Patch17:        mpg-netpbm-jpeg-fix.diff
Patch18:        mgp-yylineno-fix.patch
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  emacs-nox
BuildRequires:  flex
BuildRequires:  imake
BuildRequires:  imlib2-devel
BuildRequires:  pkgconfig
BuildRequires:  sharutils
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xmu)
Requires:       perl
Requires:       sharutils
Recommends:     imlib2
Provides:       magicpoint

%description
MagicPoint is an X Window System presentation tool. It is designed to
make simple presentations easy while making complicated presentations
possible. Its presentation file (the suffix is typically .mgp) is plain
text so that you can create presentation files quickly with your
favorite editor (Emacs, for example). The package also includes the
tools mgp2html, mgp2ps, and mgp2latex, which convert mgp presentations
into other file formats.

%prep
%setup -q -n magicpoint-%{version}
#%patch
%patch1
%patch2  -p1
# %patch3
%patch5 -p1
%patch6
%patch7 -p1
%patch8
%patch9
#patch10
%patch11
%patch13
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
cp %{SOURCE1} .
rm -rf sample/CVS

%build
autoreconf -fiv
# FIXME: you should use the %%configure macro
%configure --disable-gif \
  --enable-imlib \
  --enable-locale \
  --disable-vflib \
  --disable-freetype
xmkmf -a
make Makefiles
# hackish workaround to correct the wrong ar invocation from the default imake
find * -name Makefile | xargs sed -ie 's/ar clq/ar cq/'
make CCOPTIONS="%{optflags}"
emacs --batch --no-site -f batch-byte-compile contrib/mgp-mode20.el

%install
%make_install install.man
install -d %{buildroot}%{_bindir}
install -c contrib/mgp2html.pl %{buildroot}%{_bindir}/mgp2html
install -c contrib/mgp2latex.pl %{buildroot}%{_bindir}/mgp2latex
install -d %{buildroot}%{_datadir}/emacs/site-lisp
install -p -m644 contrib/mgp-mode20.el{,c} %{buildroot}%{_datadir}/emacs/site-lisp
cd sample
rm .cvsignore Imakefile* Makefile* README.jp

%files
%doc README README.fonts README.lang RELNOTES SYNTAX USAGE
%doc sample/README sample/
%doc README.SUSE
%{_bindir}/*
%if "%{_bindir}" != "%{_bindir}"
# mgp used to install both into /usr/bin and /usr/X11R6/bin
%{_bindir}/*
%endif
%{_prefix}/lib/X11/mgp/
%{_mandir}/man1/*
%{_datadir}/emacs/site-lisp/mgp-mode20.*

%changelog
* Thu Mar 11 2021 tiwai@suse.de
- Fix another build failure on TW due to the bad ar invocation;
  it's a result from the default Imake.tmp, so correct locally after
  creating Makefiles.
* Thu Feb  4 2021 tiwai@suse.de
- Fix build with the recent gcc, the doubly defined yylineno:
  mgp-yylineno-fix.patch
* Tue Feb 20 2018 crrodriguez@opensuse.org
- Fix BuildRequires:
  * remove xorg-x11-devel
  * remove libpng, libmng, gilib, all unused when imlib2
    is enabled
  * remove freetype2-devel, unused, app only supports
    freetype1 which is no longer available, FT2 support
    is provided via xft library.
* Wed Feb  7 2018 meissner@suse.com
- the "requires freetype" no longer seems necessary.
* Tue Nov 14 2017 mpluskal@suse.com
- Cleanup with spec-cleaner
* Mon Nov 13 2017 dimstar@opensuse.org
- Rename README.SuSE to README.SUSE, adhering to the correct
  spelling.
* Tue Jun 21 2016 tiwai@suse.de
- Fix obsoleted jpeg conversion programs to the netpbm ones:
  mpg-netpbm-jpeg-fix.diff
* Mon May 23 2016 tiwai@suse.de
- Fix the incomplete previous patch for the alpha channel
  (boo#980768):
  mgp-alpha-channel.diff
* Thu May 19 2016 tiwai@suse.de
- Implement the alpha channel support for fix the rendering bug
  of images with transparent color (boo#980768):
  mgp-alpha-channel.diff
  Refresh mgp-bilinear-zoom.diff for a workaround of transparent
  bug, too
* Wed Aug 22 2012 tiwai@suse.de
- Add recommends imlib2 to be installed automatically
* Thu Aug 16 2012 tiwai@suse.de
- Add bilinear image resampling (bnc#789418)
- Fix BadDrawable error with zoomonclk (bnc#789416)
- Fix the potential buffer overflow in imlib handling code
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Nov  8 2010 coolo@novell.com
- remove support for pre-9.1
* Tue Dec 29 2009 vuntz@opensuse.org
- Drop magicpoint-1.13a-imlib.diff: we don't use /opt/gnome
  anymore.
- Add magicpoint-imlib2.patch: taken from upstream snapshot, to
  compile with imlib2.
- Change imlib-devel/imlib-config BuildRequires to imlib2-devel.
- Remove unneeded BuildRequires: gtk-devel, libtiff-devel.
- Add xorg-x11-devel BuildRequires.
* Mon Dec  7 2009 meissner@suse.de
- rediffed fuzzy patches
* Wed Mar  5 2008 anosek@suse.cz
- updated to version 1.13a
  * m17n library support enhancement
  * add new environment variable MGPRC for the path of the .mgprc file.
  * add "psfont" directive to specify the font used by mgp2ps
  * add -g option for mgp2ps to allow users to adjust line distanc
  * add -zoomonclk option for newimage
  * allow to handle gif format images by default
  * many bug fixes
- dropped obsoleted patches (Xorg7.diff) (head.diff)
* Wed Aug  1 2007 anosek@suse.cz
- updated to version 1.12a
  * add %%tsystem directive which might be more stable than %%xsystem
  * add -rotate option for newimage
  * allow to use non-ASCI filename in slides (use -U to enable this feature)
  * many bug fixes
- disabled xft-rendering-fix.diff
- fixed compiler warnings (warnings.patch)
* Fri Mar 30 2007 rguenther@suse.de
- added bison and flex BuildRequires
* Thu Jan  4 2007 anosek@suse.cz
- fixed x11.c:364: warning: operation on 'fullscreen' may be
  undefined (compile-warning.diff)
* Tue Jul 25 2006 mmarek@suse.de
- fix build with modular Xorg
- use even more RPM_OPT_FLAGS
* Mon Apr  3 2006 mmarek@suse.cz
- fix configure script to find libraries in .../lib64 on 64bit
  [#162810] (lib64.patch)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 15 2005 mmarek@suse.cz
- package emacs mode
  [#132365]
* Tue Oct 18 2005 mmarek@suse.cz
- applied xft-rendering chache patch from tiwai@suse.de
- refreshed patches
* Wed Sep 28 2005 meissner@suse.de
- use more RPM_OPT_FLAGS.
* Fri Aug  5 2005 ltinkl@suse.cz
- update to 1.11b
- adapt patches, fix some compiler warnings
* Wed Apr 27 2005 meissner@suse.de
- fixed NULL termination.
* Mon Sep 27 2004 tiwai@suse.de
- fixed the broken freetype support (bug #39335)
- compile properly with XFT2 and libmng support
- fixed sample truetype fonts to Sazanami fonts (default on SL9.2)
- added README.SuSE for backward compatibility problem
* Wed May 19 2004 ro@suse.de
- added return values to non-void functions
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Thu Oct 23 2003 ltinkl@suse.cz
- update to 1.10a
- build with freetype2
- remake patches, throw unused ones away
* Thu Jul 24 2003 ltinkl@suse.cz
- build with imlib in /opt/gnome
* Thu Apr 10 2003 ro@suse.de
- fix deprecated head calling syntax (-1)
* Wed Jan 29 2003 ro@suse.de
- use stdarg
* Wed Jun  5 2002 ro@suse.de
- added a "AC_ARG_WITH" for freetype lib to be able to specify
  dir to search the library in
* Thu May  2 2002 mfabian@suse.de
- add configure options --disable-vflib --enable-freetype-charset16
  to support CJK TrueType fonts via freetype.
- edit default.mgp, mgprc-sample, sample-jp.mgp and sample.mgp
  a bit to use fonts available on SuSE Linux by default.
* Thu Mar 21 2002 tcrhak@suse.cz
- Fixed: for(i=0; i<0; i++) was used instead of for(i=0; i<4; i++)
  by accident in the previous fix.
* Mon Mar 18 2002 tcrhak@suse.cz
- fixed TrueType font pell-mell: iso8859-[234] coded characters
  where shown using different font then the other characters
- fixed font caching
* Wed Mar  6 2002 tcrhak@suse.cz
- added print-iso-8859-2 patch
- linked with libmng and imlib
* Thu Oct 25 2001 dan@suse.cz
- update to version 1.09a, new features:
  * the "area" directive
  * enhance "prefix" directive
- fix a seculity hole inherited from xloadimage
* Mon Aug  6 2001 cihlar@suse.cz
- update to version 1.08a
* Tue Jun  5 2001 schwab@suse.de
- Fix last change.
- Add %%suse_update_config.
- Fix invalid use of NULL.
* Mon May 28 2001 pblaha@suse.cz
- fix cast pointer on ia64
* Mon Mar 26 2001 uli@suse.de
- libungif now needs libX11, adapted configure* accordingly
* Thu Dec 14 2000 tiwai@suse.de
- fixed requires.
* Wed Sep 13 2000 tiwai@suse.de
- added sharutil to support mgpembed correctly.
- added libungif for gif support.
- changed to bzip2.
* Mon May 22 2000 cihlar@suse.cz
- added BuildRoot
- update to 1.07a
* Wed Feb 16 2000 grimmer@suse.de
- added group tag to spec file
- added URL to spec file
- use full URL to source package
- use version macro in spec file
* Fri Jan 28 2000 ro@suse.de
- freetype is in /usr/include/freetype, fixed configure.in
- updated config.sub
- man to /usr/share
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Aug  2 1999 grimmer@suse.de
- update to 1.06a
- added README.lang to docu
* Tue Jun 22 1999 grimmer@suse.de
- update to 1.05a
- now uses FreeType
* Mon Sep 28 1998 grimmer@suse.de
- new version: 1.04a
* Tue Aug 11 1998 grimmer@suse.de
- new package (Version 1.03a)
